import pytest


def test_sles_azure_csp_cli(
    host,
    is_sle_micro,
    is_suma,
    is_chost,
    get_version
):
    version = get_version()

    if is_sle_micro() or is_suma() or is_chost():
        pytest.skip('Skip image that does not contain the Azure CLI.')

    which_cmd = host.run('command -v az')
    assert which_cmd.rc == 0, \
        f"'{which_cmd.command}' failed with code {which_cmd.rc}."

    az_cmd = host.run('az --version')
    assert az_cmd.rc == 0, f"'{az_cmd.command}' failed with code {az_cmd.rc}"

    assert 'azure-cli' in az_cmd.stdout, \
        "Missing expected 'azure-cli' in version output"
    assert 'core' in az_cmd.stdout, \
        "Missing expected 'core' in version output"

    if version >= 15.0:
        assert 'msal' in az_cmd.stdout, \
            "Missing expected 'msal' in version output"
        assert 'azure-mgmt-resource' in az_cmd.stdout, \
            "Missing expected 'azure-mgmt-resource' in version output"
    else:
        assert 'telemetry' in az_cmd.stdout, \
            "Missing expected 'telemetry' in version output"



import pytest


def test_sles_gcp_csp_cli(host, is_sle_micro):
    if is_sle_micro():
        pytest.skip('Micro has product version instead of SLE version.')

    which_cmd = host.run('command -v gcloud')
    assert which_cmd.rc == 0, f"'{which_cmd.command}' failed with code {which_cmd.rc}."

    gcp_cmd = host.run('gcloud --version')
    assert gcp_cmd.rc == 0, f"'{gcp_cmd.command}' failed with code {gcp_cmd.rc}"
    assert 'Google Cloud SDK' in gcp_cmd.stdout, \
        "'Google Cloud SDK' not found in gcloud version output"
    assert 'core' in gcp_cmd.stdout, \
        "'core' not found in gcloud version output"
    assert 'minikube' in gcp_cmd.stdout, \
        "'minikube' not found in gcloud version output"



import pytest


@pytest.mark.skipinbeta
def test_sles_sap_motd(host, get_release_value, get_variant, get_version):
    motd = host.file('/etc/motd')

    if not motd.exists:
        motd = host.file('/usr/lib/motd.d/10_header')

    assert motd.exists
    assert motd.is_file

    variant = get_variant()
    version = get_version()

    if (
        'hardened' in variant or
        # SAP is hardened by default in >=16.0
        version >= 16.0
    ):
        pytest.skip(
            'Unable to validate motd in hardened images or SAP images >= 16.0.'
        )

    assert motd.contains('for SAP Applications')



import pytest


def test_sles_ec2_billing_code(
    get_ec2_billing_products,
    is_byos,
    get_release_value,
    is_suma_server,
    get_variant
):
    try:
        products = get_ec2_billing_products()
    except Exception:
        # CHOST images have no ec2metdata.
        pytest.skip(
            'ec2metadata not in image, cannot determine billing products.'
        )

    variant = get_variant()
    byos = is_byos()

    has_no_code = (
        byos or
        (variant in ('sles-sap', 'sles-sap-hardened') and not byos) or
        is_suma_server() and not byos
    )

    if has_no_code:
        assert products is None
    else:
        assert products



import pytest


def test_sles_ec2_csp_cli(host, is_sle_micro, is_suma, is_chost, get_version):
    version = get_version()

    if is_sle_micro() or is_suma() or is_chost():
        pytest.skip('Skip image that does not contain the AWS CLI.')

    which_cmd = host.run('command -v aws')
    assert which_cmd.rc == 0, \
        f"'{which_cmd.command}' failed with code {which_cmd.rc}."

    aws_cmd = host.run('aws --version')
    assert aws_cmd.rc == 0, \
        f"'{aws_cmd.command}' failed with code {aws_cmd.rc}"

    if version >= 15.0:
        assert 'aws-cli' in aws_cmd.stdout, \
            "'aws-cli' not found in aws version output"
        assert 'botocore' in aws_cmd.stdout, \
            "'botocore' not found in aws version output"
    else:
        # The python version in 12-sp5 dumps the output
        # to stderr even with exit code of 0
        assert 'aws-cli' in aws_cmd.stderr, \
            "'aws-cli' not found in aws version output"
        assert 'botocore' in aws_cmd.stderr, \
            "'botocore' not found in aws version output"
